:math:`x(t) \longleftrightarrow X(s)`

:math:`x(a t) \longleftrightarrow \frac{X(\frac{s}{a})}{\left|{a}\right|}`

:math:`x(t - \tau) \longleftrightarrow X(s) e^{- s \tau}`

:math:`\cos{\left(2 \pi f0 t \right)} \longleftrightarrow \frac{s}{4 \pi^{2} f0^{2} + s^{2}}`

:math:`\sin{\left(2 \pi f0 t \right)} \longleftrightarrow \frac{2 \pi f0}{4 \pi^{2} f0^{2} + s^{2}}`

:math:`e^{2 \mathrm{j} \pi f0 t} \longleftrightarrow \frac{1}{s \left(- \frac{2 \mathrm{j} \pi f0}{s} + 1\right)}`

:math:`1 \longleftrightarrow \frac{1}{s}`

:math:`t \longleftrightarrow \frac{1}{s^{2}}`

:math:`t^{2} \longleftrightarrow \frac{2}{s^{3}}`

:math:`\delta\left(t\right) \longleftrightarrow 1`

:math:`\delta\left(t - t0\right) \longleftrightarrow e^{- s t0}`

:math:`u\left(t\right) \longleftrightarrow \frac{1}{s}`

:math:`t u\left(t\right) \longleftrightarrow \frac{1}{s^{2}}`

:math:`\mathrm{sign}{\left(t \right)} \longleftrightarrow \frac{1}{s}`

:math:`e^{- \left|{t}\right|} \longleftrightarrow \frac{1}{s + 1}`

:math:`e^{- t} u\left(t\right) \longleftrightarrow \frac{1}{s + 1}`

:math:`\mathrm{rect}{\left(t - \frac{1}{2} \right)} \longleftrightarrow \frac{1}{s} - \frac{e^{- s}}{s}`

:math:`\mathrm{tri}{\left(t - 1 \right)} \longleftrightarrow \frac{2 e^{- s}}{s} - \frac{2 e^{- 2 s}}{s} + \frac{4 \left(\frac{s}{2} + \frac{1}{4}\right) e^{- 2 s}}{s^{2}} - \frac{2 \left(s + 1\right) e^{- s}}{s^{2}} + \frac{1}{s^{2}}`

:math:`\mathrm{ramp}{\left(t \right)} \longleftrightarrow \frac{1}{s^{2}}`

:math:`\mathrm{rampstep}{\left(t \right)} \longleftrightarrow \frac{1 - e^{- s}}{s^{2}}`

:math:`\frac{d}{d t} x(t) \longleftrightarrow s X(s) - x(0)`

:math:`\frac{d^{2}}{d t^{2}} x(t) \longleftrightarrow s^{2} X(s) - s x(0) - \left. \frac{d}{d t} x(t) \right|_{\substack{ t=0 }}`

:math:`\int\limits_{0}^{t} x(t)\, dt \longleftrightarrow \frac{X(s)}{s}`

